|Build Status|

Kubernetes Resource Provider
============================

The Kubernetes resource provider for Pulumi lets you use Kubernetes
resources in your cloud programs.

This package is meant for use with the Pulumi CLI. Please visit
`pulumi.io <https://pulumi.io>`__ for installation instructions.

Kubernetes version support
--------------------------

The ``pulumi-kubernetes`` package closely tracks the latest upstream
release, and provides access to the full API surface, including
deprecated endpoints. At a minimum, we support the current version and
the previous two versions. Older versions will likely work as well, but
are not officially supported.

See the
`CHANGELOG <https://github.com/pulumi/pulumi-kubernetes/blob/master/CHANGELOG.md>`__
for details on supported versions of Kubernetes for each version of the
``pulumi-kubernetes`` package.

.. |Build Status| image:: https://travis-ci.com/pulumi/pulumi-kubernetes.svg?token=eHg7Zp5zdDDJfTjY8ejq&branch=master
   :target: https://travis-ci.com/pulumi/pulumi-kubernetes
